@@ -2,31 +2,14 @@
 #
 # Copyright 2021-2022 NXP
 #
-# The MIT License (MIT)
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
 
 
 import asyncio
 import logging
 import sys
-
 from importlib import import_module
+
 from fc_server.core.api_svr import ApiSvr
 from fc_server.core.config import Config
 from fc_server.core.decorators import check_priority_scheduler
@@ -85,6 +68,9 @@ class Coordinator:
         # assure no seize for this job when already a seize for this job there
         self.coordinating_job_records = {}
 
+        # record timeout task for seized status
+        self.seized_status_timeout_records = {}
+
         logging.info("FC managed resource list:")
         logging.info(Config.managed_resources)
 
@@ -217,6 +203,11 @@ class Coordinator:
         # pylint: disable=consider-iterating-dictionary
         return job_id in list(self.coordinating_job_records.keys())
 
+    async def __seized_status_timeout(self, resource):
+        await asyncio.sleep(90)
+        logging.info("* %s seized status be reset to fc due to timeout", resource)
+        self.reset_resource(resource)
+
     @check_priority_scheduler()
     async def coordinate_resources(self, context, job_id, *candidated_resources):
         """
@@ -266,6 +257,15 @@ class Coordinator:
                         candidated_seized_resource,
                         context.__module__.split(".")[-1] + "_seized",
                     )
+
+                    # timeout for seized status
+                    timeout_task = asyncio.create_task(
+                        self.__seized_status_timeout(candidated_seized_resource)
+                    )
+                    self.seized_status_timeout_records[
+                        candidated_seized_resource
+                    ] = timeout_task
+
                     break
             low_priority_resources.append(candidated_seized_resource)
 
@@ -298,6 +298,11 @@ class Coordinator:
                 self.__managed_issue_disconnect_resources.append(resource)
 
     def accept_resource(self, resource, context):
+        # cancel seized status timeout task if this resource is seized from others
+        if resource in self.seized_status_timeout_records:
+            timeout_task = self.seized_status_timeout_records.pop(resource)
+            timeout_task.cancel()
+
         self.__set_resource_status(resource, context.__module__.split(".")[-1])
 
     def retire_resource(self, resource):
