@@ -2,24 +2,7 @@
 #
 # Copyright 2022 NXP
 #
-# The MIT License (MIT)
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
 
 # pylint: disable=no-member
 
@@ -27,8 +10,10 @@ import asyncio
 import logging
 import traceback
 import types
+
 import yaml
 
+from fc_common import which
 from fc_server.core import AsyncRunMixin
 from fc_server.core.config import Config
 from fc_server.core.decorators import verify_cmd_results
@@ -40,6 +25,7 @@ except ImportError:
 
 
 class Lava(AsyncRunMixin):
+    @which("lavacli", "Use 'pip3 install lavacli' to install lava client please.")
     def __init__(self):
         self.identities = Config.frameworks_config["lava"]["identities"]
         self.device_description_prefix = "[FC]"
